@@ -13,19 +13,23 @@ package org.eclipse.che.workspace.infrastructure.kubernetes.server.external;
 
 import static com.google.common.base.Strings.isNullOrEmpty;
 
-import io.fabric8.kubernetes.api.model.IntOrString;
+import com.google.common.annotations.VisibleForTesting;
 import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
-import io.fabric8.kubernetes.api.model.extensions.HTTPIngressPath;
-import io.fabric8.kubernetes.api.model.extensions.HTTPIngressPathBuilder;
-import io.fabric8.kubernetes.api.model.extensions.HTTPIngressRuleValue;
-import io.fabric8.kubernetes.api.model.extensions.HTTPIngressRuleValueBuilder;
-import io.fabric8.kubernetes.api.model.extensions.Ingress;
-import io.fabric8.kubernetes.api.model.extensions.IngressBackend;
-import io.fabric8.kubernetes.api.model.extensions.IngressBackendBuilder;
-import io.fabric8.kubernetes.api.model.extensions.IngressRule;
-import io.fabric8.kubernetes.api.model.extensions.IngressRuleBuilder;
-import io.fabric8.kubernetes.api.model.extensions.IngressSpec;
-import io.fabric8.kubernetes.api.model.extensions.IngressSpecBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath;
+import io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue;
+import io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.Ingress;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressBackend;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressBackendBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressRule;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressRuleBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressServiceBackend;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressServiceBackendBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressSpec;
+import io.fabric8.kubernetes.api.model.networking.v1.IngressSpecBuilder;
+import io.fabric8.kubernetes.api.model.networking.v1.ServiceBackendPortBuilder;
 import java.util.HashMap;
 import java.util.Map;
 import org.eclipse.che.api.core.model.workspace.config.ServerConfig;
@@ -43,12 +47,15 @@ public class ExternalServerIngressBuilder {
   private String path;
   private String name;
   private String serviceName;
-  private IntOrString servicePort;
+  private String servicePortName;
+  private Integer servicePort;
   private Map<String, ? extends ServerConfig> serversConfigs;
   private String machineName;
   private Map<String, String> annotations;
   private Map<String, String> labels;
 
+  @VisibleForTesting static final String INGRESS_PATH_TYPE = "Prefix";
+
   public ExternalServerIngressBuilder withHost(String host) {
     this.host = host;
     return this;
@@ -74,8 +81,13 @@ public class ExternalServerIngressBuilder {
     return this;
   }
 
-  public ExternalServerIngressBuilder withServicePort(String targetPortName) {
-    this.servicePort = new IntOrString(targetPortName);
+  public ExternalServerIngressBuilder withServicePort(Integer targetPort) {
+    this.servicePort = targetPort;
+    return this;
+  }
+
+  public ExternalServerIngressBuilder withServicePortName(String targetPortName) {
+    this.servicePortName = targetPortName;
     return this;
   }
 
@@ -97,14 +109,26 @@ public class ExternalServerIngressBuilder {
 
   public Ingress build() {
 
-    IngressBackend ingressBackend =
-        new IngressBackendBuilder()
-            .withServiceName(serviceName)
-            .withNewServicePort(servicePort.getStrVal())
+    ServiceBackendPortBuilder serviceBackendPortBuilder = new ServiceBackendPortBuilder();
+
+    // cannot set both port and name
+    if (!isNullOrEmpty(servicePortName)) {
+      serviceBackendPortBuilder.withName(servicePortName);
+    } else if (servicePort != null) {
+      serviceBackendPortBuilder.withNumber(servicePort);
+    }
+
+    IngressServiceBackend ingressServiceBackend =
+        new IngressServiceBackendBuilder()
+            .withPort(serviceBackendPortBuilder.build())
+            .withName(serviceName)
             .build();
 
+    IngressBackend ingressBackend =
+        new IngressBackendBuilder().withService(ingressServiceBackend).build();
+
     HTTPIngressPathBuilder httpIngressPathBuilder =
-        new HTTPIngressPathBuilder().withBackend(ingressBackend);
+        new HTTPIngressPathBuilder().withBackend(ingressBackend).withPathType(INGRESS_PATH_TYPE);
 
     if (!isNullOrEmpty(path)) {
       httpIngressPathBuilder.withPath(path);
@@ -128,7 +152,7 @@ public class ExternalServerIngressBuilder {
     ingressAnnotations.putAll(
         Annotations.newSerializer().servers(serversConfigs).machineName(machineName).annotations());
 
-    return new io.fabric8.kubernetes.api.model.extensions.IngressBuilder()
+    return new IngressBuilder()
         .withSpec(ingressSpec)
         .withMetadata(
             new ObjectMetaBuilder()
