@@ -17,8 +17,8 @@ import static org.eclipse.che.multiuser.permission.devfile.server.UserDevfileDom
 import static org.eclipse.che.multiuser.permission.devfile.server.UserDevfileDomain.UPDATE;
 
 import com.google.common.annotations.VisibleForTesting;
+import jakarta.ws.rs.Path;
 import javax.inject.Inject;
-import javax.ws.rs.Path;
 import org.eclipse.che.api.core.ForbiddenException;
 import org.eclipse.che.api.devfile.server.DevfileService;
 import org.eclipse.che.api.devfile.server.UserDevfileManager;
