@@ -84,6 +84,22 @@ public class BitbucketServerApiClientProviderTest {
     assertTrue(NoopBitbucketServerApiClient.class.isAssignableFrom(actual.getClass()));
   }
 
+  @Test(dataProvider = "httpOnlyConfig")
+  public void shouldProvideHttpAuthenticatorIfOauthConfigurationIsNotSet(
+      @Nullable String bitbucketEndpoints,
+      @Nullable String bitbucketOauth1Endpoint,
+      Set<OAuthAuthenticator> authenticators)
+      throws IOException {
+    // given
+    BitbucketServerApiProvider bitbucketServerApiProvider =
+        new BitbucketServerApiProvider(bitbucketEndpoints, bitbucketOauth1Endpoint, authenticators);
+    // when
+    BitbucketServerApiClient actual = bitbucketServerApiProvider.get();
+    // then
+    assertNotNull(actual);
+    assertTrue(HttpBitbucketServerApiClient.class.isAssignableFrom(actual.getClass()));
+  }
+
   @Test(
       expectedExceptions = ConfigurationException.class,
       expectedExceptionsMessageRegExp =
@@ -128,6 +144,14 @@ public class BitbucketServerApiClientProviderTest {
   public Object[][] noopConfig() {
     return new Object[][] {
       {null, null, null},
+      {"", "", null}
+    };
+  }
+
+  @DataProvider(name = "httpOnlyConfig")
+  public Object[][] httpOnlyConfig() {
+    return new Object[][] {
+      {"https://bitbucket.server.com", null, null},
       {"https://bitbucket.server.com, https://bitbucket2.server.com", null, null},
       {
         "https://bitbucket.server.com, https://bitbucket2.server.com",
