@@ -127,6 +127,12 @@ public class GitlabUrl implements RemoteFactoryUrl {
     return this;
   }
 
+  @Override
+  public void setDevfileFilename(String devfileName) {
+    this.devfileFilenames.clear();
+    this.devfileFilenames.add(devfileName);
+  }
+
   /**
    * Gets branch of this gitlab url
    *
@@ -198,7 +204,7 @@ public class GitlabUrl implements RemoteFactoryUrl {
             .add(hostName)
             .add("api/v4/projects")
             // use URL-encoded path to the project as a selector instead of id
-            .add(encode(username + "/" + project, Charsets.UTF_8))
+            .add(geProjectIdentifier())
             .add("repository")
             .add("files")
             .add(fileName)
@@ -210,6 +216,12 @@ public class GitlabUrl implements RemoteFactoryUrl {
     return resultUrl;
   }
 
+  private String geProjectIdentifier() {
+    return repository != null
+        ? encode(username + "/" + project + "/" + repository, Charsets.UTF_8)
+        : encode(username + "/" + project, Charsets.UTF_8);
+  }
+
   /**
    * Provides location to the repository part of the full gitlab URL.
    *
