@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2018 Red Hat, Inc.
+ * Copyright (c) 2012-2021 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -429,10 +429,7 @@ public class UserDaoTest {
   @Test(dependsOnMethods = "getAllShouldReturnAllUsersWithinSingleResponse")
   public void shouldReturnUserWithNullPasswordWhenGetAllUser() throws Exception {
     assertEquals(
-        userDao
-            .getAll(users.length, 0)
-            .getItems()
-            .stream()
+        userDao.getAll(users.length, 0).getItems().stream()
             .filter(u -> u.getPassword() == null)
             .count(),
         users.length);
