@@ -109,23 +109,6 @@ public class ServerConfigImplTest {
         serverConfig.getAttributes().get(INTERNAL_SERVER_ATTRIBUTE), Boolean.TRUE.toString());
   }
 
-  @Test
-  public void testCreateFromEndpointDevfileEndpointAttributeSet() {
-    ServerConfig serverConfig =
-        ServerConfigImpl.createFromEndpoint(new EndpointImpl("name", 123, new HashMap<>()), true);
-
-    assertTrue(serverConfig.getAttributes().containsKey(REQUIRE_SUBDOMAIN));
-    assertTrue(Boolean.parseBoolean(serverConfig.getAttributes().get(REQUIRE_SUBDOMAIN)));
-  }
-
-  @Test
-  public void testCreateFromEndpointDevfileEndpointAttributeNotSet() {
-    ServerConfig serverConfig =
-        ServerConfigImpl.createFromEndpoint(new EndpointImpl("name", 123, new HashMap<>()), false);
-
-    assertFalse(serverConfig.getAttributes().containsKey(REQUIRE_SUBDOMAIN));
-  }
-
   @Test
   public void testCreateFromEndpointDevfileEndpointAttributeNotSetWhenDefault() {
     ServerConfig serverConfig =
