@@ -1,5 +1,5 @@
 --
--- Copyright (c) 2012-2020 Red Hat, Inc.
+-- Copyright (c) 2012-2019 Red Hat, Inc.
 -- This program and the accompanying materials are made
 -- available under the terms of the Eclipse Public License 2.0
 -- which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,4 +10,8 @@
 --   Red Hat, Inc. - initial API and implementation
 --
 
-DROP TABLE externalmachine_installers;
+DROP TABLE installer_serverconf_attributes;
+DROP TABLE installer_dependencies;
+DROP TABLE installer_servers;
+DROP TABLE installer_properties;
+DROP TABLE installer;
